# Taoverse Package

This is a package containing various python modules for use in bittensor subnets.

## Metagraph

The metagraph module contains code relating to metagraph operations.

## Model

The model module contains code relating to large language models.

## Utilities

The utilities module contains code found to be generically useful in the context of subnets.